@@ -17,7 +17,7 @@ import testtools
 class TestCase(testtools.TestCase):
 
     def setUp(self):
-        super(TestCase, self).setUp()
+        super().setUp()
         stdout = self.useFixture(fixtures.StringStream('stdout')).stream
         self.useFixture(fixtures.MonkeyPatch('sys.stdout', stdout))
         stderr = self.useFixture(fixtures.StringStream('stderr')).stream
